<?php

namespace Property\Property\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Property\Property\Http\Requests\PropertyListsRequest;
use Property\Property\Models\PropertyLists;

/**
 * Admin web controller class.
 */
class PropertyListsWorkflowController extends BaseController
{

    /**
     * Workflow controller function for property_lists.
     *
     * @param Model   $property_lists
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(PropertyListsRequest $request, PropertyLists $property_lists, $step)
    {

        try {

            $property_lists->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('property::property_lists.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/property_lists/property_lists/' . $property_lists->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/property_lists/property_lists/' . $property_lists->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for property_lists.
     *
     * @param Model   $property_lists
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(PropertyLists $property_lists, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $property_lists->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('property::property_lists.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('property::admin.property_lists.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('property::admin.property_lists.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('property::admin.property_lists.message', $data)->render();

        }

    }
}
