<?php

namespace Property\Property\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Property\Property\Models\PropertyLists;

class PropertyListsAction
{
    /**
     * Perform the complete action.
     *
     * @param PropertyLists $property_lists
     *
     * @return PropertyLists
     */
    public function complete(PropertyLists $property_lists)
    {
        try {
            $property_lists->status = 'complete';
            return $property_lists->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param PropertyLists $property_lists
     *
     * @return PropertyLists
     */public function verify(PropertyLists $property_lists)
    {
        try {
            $property_lists->status = 'verify';
            return $property_lists->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param PropertyLists $property_lists
     *
     * @return PropertyLists
     */public function approve(PropertyLists $property_lists)
    {
        try {
            $property_lists->status = 'approve';
            return $property_lists->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param PropertyLists $property_lists
     *
     * @return PropertyLists
     */public function publish(PropertyLists $property_lists)
    {
        try {
            $property_lists->status = 'publish';
            return $property_lists->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param PropertyLists $property_lists
     *
     * @return PropertyLists
     */
    public function archive(PropertyLists $property_lists)
    {
        try {
            $property_lists->status = 'archive';
            return $property_lists->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param PropertyLists $property_lists
     *
     * @return PropertyLists
     */
    public function unpublish(PropertyLists $property_lists)
    {
        try {
            $property_lists->status = 'unpublish';
            return $property_lists->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
