<?php

namespace Property\Property\Workflow;

use Property\Property\Models\PropertyLists;
use Validator;

class PropertyListsValidator
{

    /**
     * Determine if the given property_lists is valid for complete status.
     *
     * @param PropertyLists $property_lists
     *
     * @return bool / Validator
     */
    public function complete(PropertyLists $property_lists)
    {
        return Validator::make($property_lists->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given property_lists is valid for verify status.
     *
     * @param PropertyLists $property_lists
     *
     * @return bool / Validator
     */
    public function verify(PropertyLists $property_lists)
    {
        return Validator::make($property_lists->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given property_lists is valid for approve status.
     *
     * @param PropertyLists $property_lists
     *
     * @return bool / Validator
     */
    public function approve(PropertyLists $property_lists)
    {
        return Validator::make($property_lists->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given property_lists is valid for publish status.
     *
     * @param PropertyLists $property_lists
     *
     * @return bool / Validator
     */
    public function publish(PropertyLists $property_lists)
    {
        return Validator::make($property_lists->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given property_lists is valid for archive status.
     *
     * @param PropertyLists $property_lists
     *
     * @return bool / Validator
     */
    public function archive(PropertyLists $property_lists)
    {
        return Validator::make($property_lists->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given property_lists is valid for unpublish status.
     *
     * @param PropertyLists $property_lists
     *
     * @return bool / Validator
     */
    public function unpublish(PropertyLists $property_lists)
    {
        return Validator::make($property_lists->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
